<?php

namespace apexl\Io\modules\product\entities;

use apexl\Io\includes\Entity;
use apexl\Io\includes\System;
use apexl\Io\modules\product\entities\operators\productRemoteReferenceIdsOperator;

class productRemoteReferenceIdsEntity extends Entity{


    public function __construct()
    {
        parent::__construct('product_remote_reference_ids');
        $this->setOperator(new productRemoteReferenceIdsOperator('product_remote_reference_ids'));
    }
}